@@ -31,43 +31,27 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <libtasn1.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <getopt.h>
 
-#ifdef HAVE_GETOPT_H
-  #include <getopt.h>
-#endif
+#include <libtasn1.h>
 
-char version_man[] = "asn1Parser (GNU libtasn1) " LIBTASN1_VERSION "\n"
-  "Written by Fabio Fiorina."
-  "\n"
-  "Copyright (C) 2002, 2006 Free Software Foundation, Inc.\n";
+#include <progname.h>
+#include <version-etc.h>
 
-char help_man[] =
-  "Usage: asn1Parser [options] FILE\n"
-  "asn1Parser reads FILE with ASN1 definitions and\n"
-  "generates a C array to use with libtasn1 functions.\n"
+static const char help_man[] =
+  "Usage: asn1Parser [OPTION] FILE\n"
+  "Read FILE with ASN.1 definitions and generate\n"
+  "a C array that is used with libtasn1 functions.\n"
   "\n"
-#ifdef HAVE_GETOPT_LONG
-  "Operation modes:\n"
-  "  -h, --help    shows this message and exit\n"
-  "  -v, --version shows version information and exit.\n"
-  "  -c, --check   checks the syntax only.\n"
+  "Mandatory arguments to long options are mandatory for short options too.\n"
+  "  -c, --check           checks the syntax only\n"
+  "  -o, --output FILE     output file\n"
+  "  -n, --name NAME       array name\n"
+  "  -h, --help            display this help and exit\n"
+  "  -v, --version         output version information and exit.\n"
   "\n"
-  "Output:\n"
-  "  -o <file>, --output <file>  output file\n"
-  "  -n <name>, --name <name>    array name\n"
-#else
-  "Operation modes:\n"
-  "  -h    shows this message and exit\n"
-  "  -v    shows version information and exit.\n"
-  "  -c    checks the syntax only.\n"
-  "\n"
-  "Output:\n"
-  "  -o <file>  output file\n"
-  "  -n <name>  array name\n"
-#endif
   "Report bugs to <" PACKAGE_BUGREPORT ">.";
 
 /********************************************************/
@@ -77,8 +61,6 @@ char help_man[] =
 int
 main(int argc,char *argv[])
 {
-
-#ifdef HAVE_GETOPT_LONG
   static struct option long_options[] =
   {
     {"help",    no_argument,       0, 'h'},
@@ -89,8 +71,6 @@ main(int argc,char *argv[])
     {0, 0, 0, 0}
   };
   int option_index = 0;
-#endif
-
  int option_result;
  char *outputFileName=NULL;
  char *inputFileName=NULL;
@@ -100,27 +80,21 @@ main(int argc,char *argv[])
  char errorDescription[MAX_ERROR_DESCRIPTION_SIZE];
  int parse_result=ASN1_SUCCESS;
 
- opterr=0; /* disable error messages from getopt */
+ set_program_name (argv[0]);
 
- printf("\n");
+ opterr=0; /* disable error messages from getopt */
 
  while(1){
 
-#ifdef HAVE_GETOPT_LONG
    option_result=getopt_long(argc,argv,"hvco:n:",long_options,&option_index);
-#else
-   option_result=getopt(argc,argv,"hvco:n:");
-#endif
 
    if(option_result == -1) break;
 
    switch(option_result){
    case 0:
-#ifdef HAVE_GETOPT_LONG
      printf("option %s",long_options[option_index].name);
      if(optarg) printf(" with arg %s",optarg);
      printf("\n");
-#endif
      break;
    case 'h':  /* HELP */
      printf("%s\n",help_man);
@@ -130,8 +104,8 @@ main(int argc,char *argv[])
      exit(0);
      break;
    case 'v':  /* VERSION */
-     printf("%s\n",version_man);
-
+     version_etc (stdout, program_name, PACKAGE, VERSION,
+		  "Fabio Fiorina", NULL);
      if(outputFileName) free(outputFileName);
      if(vectorName) free(vectorName);
      exit(0);
