@@ -392,8 +392,23 @@ test_type test_array[]={
   {ACT_READ_LENGTH,"b",NULL,5,ASN1_MEM_ERROR},
   {ACT_VISIT,"","",ASN1_PRINT_ALL,ASN1_SUCCESS},
   {ACT_DELETE,"","",0,ASN1_SUCCESS},
-  
 
+  /* Bug regression test: Empty write on 64-bit platforms */
+  {ACT_CREATE,"TEST_TREE.Checksum",0,0,ASN1_SUCCESS},
+  {ACT_WRITE,"checksum","foo",0,ASN1_SUCCESS},
+  {ACT_WRITE,"checksum","",0,ASN1_SUCCESS},
+  {ACT_ENCODING_LENGTH,"",0,4,ASN1_MEM_ERROR},
+  {ACT_ENCODING,"",0,3,ASN1_MEM_ERROR},
+  {ACT_ENCODING,"",0,4,ASN1_SUCCESS},
+  {ACT_PRINT_DER,0,0,0,ASN1_SUCCESS},
+  {ACT_DELETE,"","",0,ASN1_SUCCESS},
+  {ACT_CREATE,"TEST_TREE.Checksum",0,0,ASN1_SUCCESS},
+  {ACT_DECODING,0,0,0,ASN1_SUCCESS}, 
+  {ACT_DECODING_ELEMENT,"checksum",0,0,ASN1_SUCCESS},
+  {ACT_READ,"checksum","",0,ASN1_SUCCESS},
+  {ACT_READ_LENGTH,"checksum",NULL,0,ASN1_SUCCESS}, /* MEM_FAILURE? */
+  {ACT_VISIT,"","",ASN1_PRINT_ALL,ASN1_SUCCESS},
+  {ACT_DELETE,"","",0,ASN1_SUCCESS},
 
   /* end */
   {ACT_NULL}
