@@ -13,6 +13,41 @@ const ASN1_ARRAY_TYPE Test_tree_asn1_tab[]={
   {"pkix",1073741825,"7"},
   {"id-mod",1073741825,"0"},
   {"id-pkix1-implicit-88",1,"2"},
+  {"KrbError",1610620933,0},
+  {0,1073746952,"30"},
+  {"pvno",536879107,0},
+  {0,4104,"0"},
+  {"CertTemplate",1610612741,0},
+  {"version",1610637315,0},
+  {0,4104,"0"},
+  {"issuer",1610637314,"Name"},
+  {0,4104,"3"},
+  {"validity",536895491,0},
+  {0,4104,"4"},
+  {"Name",1610612754,0},
+  {"rdnSequence",2,"RDNSequence"},
+  {"RDNSequence",1073741826,"RelativeDistinguishedName"},
+  {"RelativeDistinguishedName",1612709903,0},
+  {"MAX",1074266122,"1"},
+  {0,2,"AttributeTypeAndValue"},
+  {"AttributeTypeAndValue",1610612741,0},
+  {"type",1073741826,"AttributeType"},
+  {"value",2,"AttributeValue"},
+  {"AttributeType",1073741836,0},
+  {"AttributeValue",1073741837,0},
+  {"sequenceEmpty",1610612741,0},
+  {"int1",1073741827,0},
+  {"seq1",1610620930,"Sequence_octetTest1"},
+  {0,4104,"1"},
+  {"set1",536879119,0},
+  {0,1073743880,"2"},
+  {0,3,0},
+  {"IndefiniteLengthTest",1610612741,0},
+  {"seq1",1610620930,"Sequence_octetTest1"},
+  {0,4104,"1"},
+  {"set1",1610612751,0},
+  {0,12,0},
+  {"int1",3,0},
   {"OidTest",1610612741,0},
   {"oid3",1610653708,0},
   {0,1073741833,"id-Test"},
@@ -75,7 +110,7 @@ const ASN1_ARRAY_TYPE Test_tree_asn1_tab[]={
   {0,1073741825,"3"},
   {0,1,"4"},
   {"Sequence_octetTest1",1610612741,0},
-  {"int",3,0},
+  {"int",16387,0},
   {"AnyTest2",1610612754,0},
   {"str",1073741831,0},
   {"int",3,0},
